@@ -244,10 +244,9 @@ fit.adapt.random2byclass.randomLCA <- function(outcomes,freq,nclass=2,initoutcom
     classprob <- final$classprob
     
     np <- length(optim.fit$estimate)
-    aic <- 2*optim.fit$minimum+2*np
-    bic <- 2*optim.fit$minimum+log(sum(freq))*np
+    nobs <- sum(freq)
     deviance <- 2*sum(ifelse(freq==0,0,freq*log(freq/fitted)))
     list(fit=optim.fit,nclass=nclass,classp=classp,outcomep=outcomep,lambdacoef=lambdacoef,taucoef=exp(ltaucoef),se=separ,
-        aic=aic,bic=bic,np=np,log.Lik=-optim.fit$minimum,freq=freq,fitted=fitted,ranef=ranef
+       np=np,nobs=nobs,logLik=-optim.fit$minimum,freq=freq,fitted=fitted,ranef=ranef
     ,classprob=classprob,deviance=deviance)
 }
